@@ -1,5 +1,5 @@
  /* BoCA - BonkEnc Component Architecture
-  * Copyright (C) 2007-2015 Robert Kausch <robert.kausch@freac.org>
+  * Copyright (C) 2007-2021 Robert Kausch <robert.kausch@freac.org>
   *
   * This program is free software; you can redistribute it and/or
   * modify it under the terms of the GNU General Public License as
@@ -25,13 +25,14 @@ namespace BoCA
 	{
 		private:
 			CDInfo		 cdInfo;
+
+			static String	 ReplaceFullWidthChars(const String &);
 		public:
 					 CDText();
 					~CDText();
 
 			Int		 ReadCDText(Int);
 
-			Int		 ClearCDInfo();
 			const CDInfo	&GetCDInfo() const;
 	};
 };
