@@ -1,5 +1,5 @@
  /* BoCA - BonkEnc Component Architecture
-  * Copyright (C) 2007-2021 Robert Kausch <robert.kausch@freac.org>
+  * Copyright (C) 2007-2022 Robert Kausch <robert.kausch@freac.org>
   *
   * This program is free software; you can redistribute it and/or
   * modify it under the terms of the GNU General Public License as
@@ -21,12 +21,11 @@ AACDECODER_DECODEFRAME		 ex_aacDecoder_DecodeFrame		= NIL;
 AACDECODER_CLOSE		 ex_aacDecoder_Close			= NIL;
 AACDECODER_GETLIBINFO		 ex_aacDecoder_GetLibInfo		= NIL;
 
-MP4READPROVIDER			 ex_MP4ReadProvider			= NIL;
+MP4READ				 ex_MP4Read				= NIL;
+MP4READCALLBACKS		 ex_MP4ReadCallbacks			= NIL;
 MP4CLOSE			 ex_MP4Close				= NIL;
 MP4FREE				 ex_MP4Free				= NIL;
-MP4GETNUMBEROFTRACKS		 ex_MP4GetNumberOfTracks		= NIL;
 MP4FINDTRACKID			 ex_MP4FindTrackId			= NIL;
-MP4GETTRACKTYPE			 ex_MP4GetTrackType			= NIL;
 MP4GETTRACKAUDIOMPEG4TYPE	 ex_MP4GetTrackAudioMpeg4Type		= NIL;
 MP4GETTRACKESCONFIGURATION	 ex_MP4GetTrackESConfiguration		= NIL;
 MP4GETTRACKTIMESCALE		 ex_MP4GetTrackTimeScale		= NIL;
@@ -79,12 +78,11 @@ Bool LoadMP4v2DLL()
 
 	if (mp4v2dll == NIL) return False;
 
-	ex_MP4ReadProvider		= (MP4READPROVIDER) mp4v2dll->GetFunctionAddress("MP4ReadProvider");
+	ex_MP4Read			= (MP4READ) mp4v2dll->GetFunctionAddress("MP4Read");
+	ex_MP4ReadCallbacks		= (MP4READCALLBACKS) mp4v2dll->GetFunctionAddress("MP4ReadCallbacks");
 	ex_MP4Close			= (MP4CLOSE) mp4v2dll->GetFunctionAddress("MP4Close");
 	ex_MP4Free			= (MP4FREE) mp4v2dll->GetFunctionAddress("MP4Free");
-	ex_MP4GetNumberOfTracks		= (MP4GETNUMBEROFTRACKS) mp4v2dll->GetFunctionAddress("MP4GetNumberOfTracks");
 	ex_MP4FindTrackId		= (MP4FINDTRACKID) mp4v2dll->GetFunctionAddress("MP4FindTrackId");
-	ex_MP4GetTrackType		= (MP4GETTRACKTYPE) mp4v2dll->GetFunctionAddress("MP4GetTrackType");
 	ex_MP4GetTrackAudioMpeg4Type	= (MP4GETTRACKAUDIOMPEG4TYPE) mp4v2dll->GetFunctionAddress("MP4GetTrackAudioMpeg4Type");
 	ex_MP4GetTrackESConfiguration	= (MP4GETTRACKESCONFIGURATION) mp4v2dll->GetFunctionAddress("MP4GetTrackESConfiguration");
 	ex_MP4GetTrackTimeScale		= (MP4GETTRACKTIMESCALE) mp4v2dll->GetFunctionAddress("MP4GetTrackTimeScale");
@@ -96,12 +94,11 @@ Bool LoadMP4v2DLL()
 	ex_MP4ItmfGetItemsByMeaning	= (MP4ITMFGETITEMSBYMEANING) mp4v2dll->GetFunctionAddress("MP4ItmfGetItemsByMeaning");
 	ex_MP4ItmfItemListFree		= (MP4ITMFITEMLISTFREE) mp4v2dll->GetFunctionAddress("MP4ItmfItemListFree");
 
-	if (ex_MP4ReadProvider			== NIL ||
+	if (ex_MP4Read				== NIL ||
+	    ex_MP4ReadCallbacks			== NIL ||
 	    ex_MP4Close				== NIL ||
 	    ex_MP4Free				== NIL ||
-	    ex_MP4GetNumberOfTracks		== NIL ||
 	    ex_MP4FindTrackId			== NIL ||
-	    ex_MP4GetTrackType			== NIL ||
 	    ex_MP4GetTrackAudioMpeg4Type	== NIL ||
 	    ex_MP4GetTrackESConfiguration	== NIL ||
 	    ex_MP4GetTrackTimeScale		== NIL ||
