@@ -1,5 +1,5 @@
  /* BoCA - BonkEnc Component Architecture
-  * Copyright (C) 2007-2015 Robert Kausch <robert.kausch@freac.org>
+  * Copyright (C) 2007-2022 Robert Kausch <robert.kausch@freac.org>
   *
   * This program is free software; you can redistribute it and/or
   * modify it under the terms of the GNU General Public License as
@@ -12,7 +12,7 @@
 
 #include <smooth.h>
 
-#include "wmsdk/wmsdk.h"
+#include <wmsdk/wmsdk.h>
 
 using namespace smooth;
 using namespace smooth::System;
