@@ -1,5 +1,5 @@
  /* BoCA - BonkEnc Component Architecture
-  * Copyright (C) 2007-2017 Robert Kausch <robert.kausch@freac.org>
+  * Copyright (C) 2007-2022 Robert Kausch <robert.kausch@freac.org>
   *
   * This program is free software; you can redistribute it and/or
   * modify it under the terms of the GNU General Public License as
@@ -23,6 +23,12 @@ namespace BoCA
 
 			Buffer<Int64>		 samplesBuffer;
 
+			Bool			 applyDither;
+			Int			 ditherType;
+			UnsignedInt		 ditherIndex;
+
+			static Void		 GenerateDither();
+
 			Void			 TransformSamples(const UnsignedByte *, const Format &, UnsignedByte *, const Format &, Int);
 		public:
 			static const String	&GetComponentSpecs();
