@@ -1,5 +1,5 @@
  /* BoCA - BonkEnc Component Architecture
-  * Copyright (C) 2007-2020 Robert Kausch <robert.kausch@freac.org>
+  * Copyright (C) 2007-2022 Robert Kausch <robert.kausch@freac.org>
   *
   * This program is free software; you can redistribute it and/or
   * modify it under the terms of the GNU General Public License as
@@ -67,7 +67,7 @@ const String &BoCA::EncoderCoreAudio::GetComponentSpecs()
 			<min alias=\"min\">8</min>							\
 			<max alias=\"max\">192</max>							\
 		      </range>										\
-		      <switch name=\"Write raw AAC files\" argument=\"--raw\"/>				\
+		      <switch name=\"Create ADTS AAC files (no MP4 container)\" argument=\"--adts\"/>	\
 		    </parameters>									\
 		  </component>										\
 													\
@@ -425,7 +425,7 @@ Bool BoCA::EncoderCoreAudio::Deactivate()
 				boca.DeleteComponent(tagger);
 			}
 		}
-		else
+		else if (mp4v2dll != NIL)
 		{
 			/* Optimize file even when no tags are written.
 			 */
@@ -533,9 +533,7 @@ Int BoCA::EncoderCoreAudio::EncodeFrames(Bool flush)
 	{
 		SuperWorker	*workerToUse = workers.GetNth(nextWorker % workers.Length());
 
-		while (!workerToUse->IsReady()) S::System::System::Sleep(1);
-
-		workerToUse->Lock();
+		workerToUse->WaitUntilReady();
 
 		/* See if the worker has some packets for us.
 		 */
@@ -544,7 +542,6 @@ Int BoCA::EncoderCoreAudio::EncodeFrames(Bool flush)
 		/* Pass new frames to worker.
 		 */
 		workerToUse->Encode(samplesBuffer, framesProcessed * bytesPerFrame, flush ? samplesBuffer.Size() : bytesPerFrame * framesToProcess, flush);
-		workerToUse->Release();
 
 		framesProcessed += framesToProcess - (flush ? 0 : overlap);
 
@@ -565,16 +562,12 @@ Int BoCA::EncoderCoreAudio::EncodeFrames(Bool flush)
 	{
 		SuperWorker	*workerToUse = workers.GetNth(nextWorker % workers.Length());
 
-		while (!workerToUse->IsReady()) S::System::System::Sleep(1);
-
-		workerToUse->Lock();
+		workerToUse->WaitUntilReady();
 
 		/* See if the worker has some packets for us.
 		 */
 		if (workerToUse->GetPacketSizes().Length() != 0) dataLength += ProcessPackets(workerToUse->GetPackets(), workerToUse->GetPacketSizes(), workerToUse->GetPacketInfos(), nextWorker == workers.Length(), nextWorker >= 2 * workers.Length());
 
-		workerToUse->Release();
-
 		nextWorker++;
 	}
 
@@ -796,27 +789,39 @@ Bool BoCA::EncoderCoreAudio::ConvertArguments(Config *config)
 
 	static const String	 encoderID = "coreaudio-enc";
 
+	/* Set default values.
+	 */
+	if (!config->GetIntValue("Settings", "UserSpecifiedConfig", False))
+	{
+		config->SetIntValue(ConfigureCoreAudio::ConfigID, "MP4Container", True);
+
+		config->SetIntValue(ConfigureCoreAudio::ConfigID, "Codec", CA::kAudioFormatMPEG4AAC);
+		config->SetIntValue(ConfigureCoreAudio::ConfigID, "Bitrate", 64);
+	}
+
 	/* Get command line settings.
 	 */
-	Int	 bitrate = 64;
-	String	 format	 = "AAC";
+	Bool	 rawAAC	    = config->GetIntValue(encoderID, "Create ADTS AAC files (no MP4 container)", !config->GetIntValue(ConfigureCoreAudio::ConfigID, "MP4Container", True));
 
-	if (config->GetIntValue(encoderID, "Set Bitrate per channel", False)) bitrate = config->GetIntValue(encoderID, "Bitrate per channel", bitrate);
-	if (config->GetIntValue(encoderID, "Set Output format", False))	      format  = config->GetStringValue(encoderID, "Output format", format).ToUpper();
+	Int	 bitrate    = config->GetIntValue(ConfigureCoreAudio::ConfigID, "Bitrate", 64);
+	Int	 format	    = config->GetIntValue(ConfigureCoreAudio::ConfigID, "Codec", CA::kAudioFormatMPEG4AAC);
+	String	 formatName = "AAC";
+
+	if (format == CA::kAudioFormatAppleLossless) formatName = "ALAC";
+
+	if (config->GetIntValue(encoderID, "Set Bitrate per channel", False)) bitrate	 = config->GetIntValue(encoderID, "Bitrate per channel", bitrate);
+	if (config->GetIntValue(encoderID, "Set Output format", False))	      formatName = config->GetStringValue(encoderID, "Output format", formatName).ToUpper();
 
 	/* Set configuration values.
 	 */
-	config->SetIntValue(ConfigureCoreAudio::ConfigID, "MP4Container", !config->GetIntValue(encoderID, "Write raw AAC files", False) || format == "ALAC");
+	config->SetIntValue(ConfigureCoreAudio::ConfigID, "MP4Container", !rawAAC || formatName == "ALAC");
 
+	if	(formatName == "AAC" ) format = CA::kAudioFormatMPEG4AAC;
+	else if (formatName == "ALAC") format = CA::kAudioFormatAppleLossless;
+
+	config->SetIntValue(ConfigureCoreAudio::ConfigID, "Codec", format);
 	config->SetIntValue(ConfigureCoreAudio::ConfigID, "Bitrate", Math::Max(8, Math::Min(256, bitrate)));
 
-	Int	 audioFormat = CA::kAudioFormatMPEG4AAC;
-
-	if	(format == "AAC" ) audioFormat = CA::kAudioFormatMPEG4AAC;
-	else if (format == "ALAC") audioFormat = CA::kAudioFormatAppleLossless;
-
-	config->SetIntValue(ConfigureCoreAudio::ConfigID, "Codec", audioFormat);
-
 	return True;
 }
 
