@@ -1,5 +1,5 @@
  /* BoCA - BonkEnc Component Architecture
-  * Copyright (C) 2007-2021 Robert Kausch <robert.kausch@freac.org>
+  * Copyright (C) 2007-2022 Robert Kausch <robert.kausch@freac.org>
   *
   * This program is free software; you can redistribute it and/or
   * modify it under the terms of the GNU General Public License as
@@ -86,7 +86,7 @@ const String &BoCA::EncoderCoreAudioConnect::GetComponentSpecs()
 			<min alias=\"min\">8</min>							\
 			<max alias=\"max\">192</max>							\
 		      </range>										\
-		      <switch name=\"Write raw AAC files\" argument=\"--raw\"/>				\
+		      <switch name=\"Create ADTS AAC files (no MP4 container)\" argument=\"--adts\"/>	\
 		    </parameters>									\
 		  </component>										\
 													\
@@ -299,7 +299,7 @@ Bool BoCA::EncoderCoreAudioConnect::Deactivate()
 				boca.DeleteComponent(tagger);
 			}
 		}
-		else
+		else if (mp4v2dll != NIL)
 		{
 			/* Optimize file even when no tags are written.
 			 */
@@ -590,7 +590,7 @@ Bool BoCA::EncoderCoreAudioConnect::ConvertArguments(Config *config)
 
 	/* Get command line settings.
 	 */
-	Bool	 rawAAC	    = config->GetIntValue(encoderID, "Write raw AAC files", !config->GetIntValue(ConfigureCoreAudio::ConfigID, "MP4Container", True));
+	Bool	 rawAAC	    = config->GetIntValue(encoderID, "Create ADTS AAC files (no MP4 container)", !config->GetIntValue(ConfigureCoreAudio::ConfigID, "MP4Container", True));
 
 	Int	 bitrate    = config->GetIntValue(ConfigureCoreAudio::ConfigID, "Bitrate", 64);
 	Int	 format	    = config->GetIntValue(ConfigureCoreAudio::ConfigID, "Codec", CA::kAudioFormatMPEG4AAC);
