@@ -1,5 +1,5 @@
  /* BoCA - BonkEnc Component Architecture
-  * Copyright (C) 2007-2020 Robert Kausch <robert.kausch@freac.org>
+  * Copyright (C) 2007-2022 Robert Kausch <robert.kausch@freac.org>
   *
   * This program is free software; you can redistribute it and/or
   * modify it under the terms of the GNU General Public License as
@@ -24,6 +24,18 @@ const String &BoCA::EncoderFLAC::GetComponentSpecs()
 
 	if (flacdll != NIL)
 	{
+		const Array<String>	&flacVersion = String(*ex_FLAC__VERSION_STRING).Explode(".");
+
+		Int	 maxBitDepth   = 24;
+		Int	 maxSampleRate = 655350;
+
+		if ( flacVersion.GetNth(0).ToInt() >  1 ||
+		    (flacVersion.GetNth(0).ToInt() == 1 && flacVersion.GetNth(1).ToInt() >= 4))
+		{
+			maxBitDepth   = 32;
+			maxSampleRate = 1048575;
+		}
+
 		componentSpecs = "										\
 														\
 		  <?xml version=\"1.0\" encoding=\"UTF-8\"?>							\
@@ -49,7 +61,7 @@ const String &BoCA::EncoderFLAC::GetComponentSpecs()
 			      <name>Ogg FLAC Files</name>							\
 			      <lossless>true</lossless>								\
 			      <extension>oga</extension>							\
-			      <tag id=\"flac-tag\" mode=\"other\">FLAC Metadata</tag>				\
+			      <tag id=\"vorbis-tag\" mode=\"other\">Vorbis Comment</tag>			\
 			    </format>										\
 														\
 			");
@@ -57,8 +69,27 @@ const String &BoCA::EncoderFLAC::GetComponentSpecs()
 
 		componentSpecs.Append("										\
 														\
-		    <input bits=\"8-24\" channels=\"1-8\"/>							\
+		    <input bits=\"8-").Append(String::FromInt(maxBitDepth)).Append("\"				\
+			   channels=\"1-8\"									\
+			   rate=\"1-").Append(String::FromInt(maxSampleRate)).Append("\"/>			\
 		    <parameters>										\
+														\
+		");
+
+		if (*ex_FLAC_API_SUPPORTS_OGG_FLAC == 1)
+		{
+			componentSpecs.Append("									\
+														\
+		      <selection name=\"Format\" argument=\"-f %VALUE\" default=\"flac\">			\
+			<option alias=\"FLAC\">flac</option>							\
+			<option alias=\"Ogg FLAC\">ogg</option>							\
+		      </selection>										\
+														\
+			");
+		}
+
+		componentSpecs.Append("										\
+														\
 		      <range name=\"Compression level\" argument=\"-c %VALUE\">					\
 			<min alias=\"fastest\">0</min>								\
 			<max alias=\"best\">8</max>								\
@@ -95,13 +126,11 @@ const String &BoCA::EncoderFLAC::GetComponentSpecs()
 
 Void smooth::AttachDLL(Void *instance)
 {
-	LoadOggDLL();
 	LoadFLACDLL();
 }
 
 Void smooth::DetachDLL()
 {
-	FreeOggDLL();
 	FreeFLACDLL();
 }
 
@@ -166,7 +195,7 @@ Bool BoCA::EncoderFLAC::Activate()
 
 		if (tagger != NIL)
 		{
-			/* Disable writing cover art to Vorbis comment tags for FLAC files.
+			/* Disable writing cover art to Vorbis Comment tags for FLAC files.
 			 */
 			Config	*taggerConfig = Config::Copy(config);
 
@@ -228,7 +257,7 @@ Bool BoCA::EncoderFLAC::Activate()
 
 	/* Add picture metadata object.
 	 */
-	if (config->GetIntValue("Tags", "CoverArtWriteToTags", True) && config->GetIntValue("Tags", "CoverArtWriteToFLACMetadata", True))
+	if (config->GetIntValue("Tags", "EnableFLACMetadata", True) && config->GetIntValue("Tags", "CoverArtWriteToTags", True) && config->GetIntValue("Tags", "CoverArtWriteToFLACMetadata", True))
 	{
 		for (Int i = 0; i < track.pictures.Length(); i++)
 		{
@@ -341,7 +370,23 @@ Bool BoCA::EncoderFLAC::Deactivate()
 
 	/* Fix chapter marks in Vorbis Comments.
 	 */
-	FixChapterMarks();
+	if (config->GetIntValue("Tags", "EnableFLACMetadata", True) && track.tracks.Length() > 0 && config->GetIntValue("Tags", "WriteChapters", True))
+	{
+		driver->Close();
+
+		AS::Registry		&boca = AS::Registry::Get();
+		AS::TaggerComponent	*tagger = NIL;
+
+		if (config->GetIntValue(ConfigureFLAC::ConfigID, "FileFormat", 0) == 0 || *ex_FLAC_API_SUPPORTS_OGG_FLAC == 0) tagger = (AS::TaggerComponent *) boca.CreateComponentByID("flac-tag");
+		else													       tagger = (AS::TaggerComponent *) boca.CreateComponentByID("vorbis-tag");
+
+		if (tagger != NIL)
+		{
+			tagger->UpdateStreamInfo(track.outputFile, track);
+
+			boca.DeleteComponent(tagger);
+		}
+	}
 
 	return True;
 }
@@ -365,6 +410,8 @@ Int BoCA::EncoderFLAC::WriteData(Buffer<UnsignedByte> &data)
 
 		else if (format.bits == 24 && endianness == EndianLittle) buffer[i] = (data[3 * i + 2] << 24 | data[3 * i + 1] << 16 | data[3 * i    ] << 8) / 256;
 		else if (format.bits == 24 && endianness == EndianBig	) buffer[i] = (data[3 * i    ] << 24 | data[3 * i + 1] << 16 | data[3 * i + 2] << 8) / 256;
+
+		else if (format.bits == 32				) buffer[i] = ((int32_t *) (UnsignedByte *) data)[i];
 	}
 
 	ex_FLAC__stream_encoder_process_interleaved(encoder, buffer, data.Size() / (format.bits / 8) / format.channels);
@@ -372,126 +419,6 @@ Int BoCA::EncoderFLAC::WriteData(Buffer<UnsignedByte> &data)
 	return bytesWritten;
 }
 
-Bool BoCA::EncoderFLAC::FixChapterMarks()
-{
-	if (track.tracks.Length() == 0 || !config->GetIntValue("Tags", "WriteChapters", True)) return True;
-
-	/* Fill buffer with Vorbis Comment block.
-	 */
-	Buffer<UnsignedByte>	 buffer;
-	Int			 position = 0;
-	ogg_page		 og	  = { 0 };
-
-	if (config->GetIntValue(ConfigureFLAC::ConfigID, "FileFormat", 0) == 0 || *ex_FLAC_API_SUPPORTS_OGG_FLAC == 0)
-	{
-		driver->Seek(4);
-
-		/* Find Vorbis Comment block and read it into buffer.
-		 */
-		UnsignedByte	 header[4] = { 0 };
-
-		while (!(header[0] & 0x80))
-		{
-			driver->ReadData(header, 4);
-
-			Int	 size = header[1] << 16 | header[2] << 8 | header[3];
-
-			if ((header[0] & 0x7F) == 4)
-			{
-				buffer.Resize(size);
-				position = driver->GetPos();
-
-				driver->ReadData(buffer, size);
-
-				break;
-			}
-
-			driver->Seek(driver->GetPos() + size);
-		}
-	}
-	else if (ex_ogg_page_checksum_set != NIL)
-	{
-		driver->Seek(0);
-
-		/* Skip first Ogg page and read second into buffer.
-		 */
-		for (Int i = 0; i < 2; i++)
-		{
-			driver->Seek(driver->GetPos() + 26);
-
-			Int		 dataSize    = 0;
-			UnsignedByte	 segments    = 0;
-			UnsignedByte	 segmentSize = 0;
-
-			driver->ReadData(&segments, 1);
-
-			for (Int i = 0; i < segments; i++) { driver->ReadData(&segmentSize, 1); dataSize += segmentSize; }
-
-			buffer.Resize(27 + segments + dataSize);
-			position = driver->GetPos() - segments - 27;
-
-			driver->Seek(position);
-			driver->ReadData(buffer, buffer.Size());
-
-			og.header     = buffer;
-			og.header_len = 27 + segments;
-			og.body	      = buffer + og.header_len;
-			og.body_len   = dataSize;
-		}
-	}
-
-	/* Update chapter marks.
-	 */
-	if (buffer.Size() > 0)
-	{
-		Int64	 offset = 0;
-
-		for (Int i = 0; i < track.tracks.Length(); i++)
-		{
-			const Track	&chapterTrack  = track.tracks.GetNth(i);
-			const Format	&chapterFormat = chapterTrack.GetFormat();
-
-			for (Int b = 0; b < buffer.Size() - 23; b++)
-			{
-				if (buffer[b + 0] != 'C' || buffer[b + 1] != 'H' || buffer[b + 2] != 'A' || buffer[b +  3] != 'P' ||
-				    buffer[b + 4] != 'T' || buffer[b + 5] != 'E' || buffer[b + 6] != 'R' || buffer[b + 10] != '=') continue;
-
-				String	 id;
-
-				id[0] = buffer[b + 7];
-				id[1] = buffer[b + 8];
-				id[2] = buffer[b + 9];
-
-				if (id.ToInt() != i + 1) continue;
-
-				String	 value	= String(offset / chapterFormat.rate / 60 / 60 < 10 ? "0" : "").Append(String::FromInt(offset / chapterFormat.rate / 60 / 60)).Append(":")
-						 .Append(offset / chapterFormat.rate / 60 % 60 < 10 ? "0" : "").Append(String::FromInt(offset / chapterFormat.rate / 60 % 60)).Append(":")
-						 .Append(offset / chapterFormat.rate % 60      < 10 ? "0" : "").Append(String::FromInt(offset / chapterFormat.rate % 60)).Append(".")
-						 .Append(Math::Round(offset % chapterFormat.rate * 1000.0 / chapterFormat.rate) < 100 ?
-							(Math::Round(offset % chapterFormat.rate * 1000.0 / chapterFormat.rate) <  10 ?  "00" : "0") : "").Append(String::FromInt(Math::Round(offset % chapterFormat.rate * 1000.0 / chapterFormat.rate)));
-
-				for (Int p = 0; p < 12; p++) buffer[b + 11 + p] = value[p];
-
-				break;
-			}
-
-			if	(chapterTrack.length	   >= 0) offset += chapterTrack.length;
-			else if (chapterTrack.approxLength >= 0) offset += chapterTrack.approxLength;
-		}
-
-		/* Write page back to file.
-		 */
-		if (config->GetIntValue(ConfigureFLAC::ConfigID, "FileFormat", 0) == 1 && *ex_FLAC_API_SUPPORTS_OGG_FLAC == 1) ex_ogg_page_checksum_set(&og);
-
-		driver->Seek(position);
-		driver->WriteData(buffer, buffer.Size());
-	}
-
-	driver->Seek(driver->GetSize());
-
-	return True;
-}
-
 Bool BoCA::EncoderFLAC::SetOutputFormat(Int n)
 {
 	Config	*config = Config::Get();
@@ -503,14 +430,20 @@ Bool BoCA::EncoderFLAC::SetOutputFormat(Int n)
 
 String BoCA::EncoderFLAC::GetOutputFileExtension() const
 {
-	const Config	*config = GetConfiguration();
+	String	 extension = "flac";
 
-	switch (config->GetIntValue(ConfigureFLAC::ConfigID, "FileFormat", 0))
+	if (*ex_FLAC_API_SUPPORTS_OGG_FLAC == 1)
 	{
-		default:
-		case  0: return "flac";
-		case  1: return *ex_FLAC_API_SUPPORTS_OGG_FLAC == 1 ? "oga" : "flac";
+		Config	*config = Config::Copy(GetConfiguration());
+
+		ConvertArguments(config);
+
+		if (config->GetIntValue(ConfigureFLAC::ConfigID, "FileFormat", 0) == 1) extension = "oga";
+
+		Config::Free(config);
 	}
+
+	return extension;
 }
 
 Bool BoCA::EncoderFLAC::ConvertArguments(Config *config)
@@ -519,14 +452,38 @@ Bool BoCA::EncoderFLAC::ConvertArguments(Config *config)
 
 	static const String	 encoderID = "flac-enc";
 
+	/* Set default values.
+	 */
+	if (!config->GetIntValue("Settings", "UserSpecifiedConfig", False))
+	{
+		config->SetIntValue(ConfigureFLAC::ConfigID, "FileFormat", 0);
+		config->SetIntValue(ConfigureFLAC::ConfigID, "Preset", -1);
+
+		config->SetIntValue(ConfigureFLAC::ConfigID, "DoMidSideStereo", False);
+		config->SetIntValue(ConfigureFLAC::ConfigID, "DoExhaustiveModelSearch", False);
+		config->SetIntValue(ConfigureFLAC::ConfigID, "DoQLPCoeffPrecSearch", False);
+
+		config->SetIntValue(ConfigureFLAC::ConfigID, "Blocksize", 4096);
+		config->SetIntValue(ConfigureFLAC::ConfigID, "MaxLPCOrder", 8);
+		config->SetIntValue(ConfigureFLAC::ConfigID, "QLPCoeffPrecision", 0);
+		config->SetIntValue(ConfigureFLAC::ConfigID, "MinResidualPartitionOrder", 0);
+		config->SetIntValue(ConfigureFLAC::ConfigID, "MaxResidualPartitionOrder", 5);
+	}
+
 	/* Get command line settings.
 	 */
-	Int	 preset	   = -1;
-	Int	 blocksize = 4096;
-	Int	 lpc	   = 8;
-	Int	 qlp	   = 0;
-	Int	 rice	   = 5;
+	Bool	 midSideStereo	  = config->GetIntValue(encoderID, "Use mid-side stereo", config->GetIntValue(ConfigureFLAC::ConfigID, "DoMidSideStereo", False));
+	Bool	 exhaustiveSearch = config->GetIntValue(encoderID, "Do exhaustive model search", config->GetIntValue(ConfigureFLAC::ConfigID, "DoExhaustiveModelSearch", False));
+	Bool	 qlpCoeffSearch   = config->GetIntValue(encoderID, "Do exhaustive QLP coefficient search", config->GetIntValue(ConfigureFLAC::ConfigID, "DoQLPCoeffPrecSearch", False));
 
+	String	 format		  = config->GetIntValue(ConfigureFLAC::ConfigID, "FileFormat", 0) == 0 ? "flac" : "ogg";
+	Int	 preset		  = config->GetIntValue(ConfigureFLAC::ConfigID, "Preset", -1);
+	Int	 blocksize	  = config->GetIntValue(ConfigureFLAC::ConfigID, "Blocksize", 4096);
+	Int	 lpc		  = config->GetIntValue(ConfigureFLAC::ConfigID, "MaxLPCOrder", 8);
+	Int	 qlp		  = config->GetIntValue(ConfigureFLAC::ConfigID, "QLPCoeffPrecision", 0);
+	Int	 rice		  = config->GetIntValue(ConfigureFLAC::ConfigID, "MaxResidualPartitionOrder", 5);
+
+	if (config->GetIntValue(encoderID, "Set Format", False))		       format	 = config->GetStringValue(encoderID, "Format", format).ToLower();
 	if (config->GetIntValue(encoderID, "Set Compression level", False))	       preset	 = config->GetIntValue(encoderID, "Compression level", preset);
 	if (config->GetIntValue(encoderID, "Set Block size", False))		       blocksize = config->GetIntValue(encoderID, "Block size", blocksize);
 	if (config->GetIntValue(encoderID, "Set Max LPC order", False))		       lpc	 = config->GetIntValue(encoderID, "Max LPC order", lpc);
@@ -535,16 +492,16 @@ Bool BoCA::EncoderFLAC::ConvertArguments(Config *config)
 
 	/* Set configuration values.
 	 */
+	config->SetIntValue(ConfigureFLAC::ConfigID, "FileFormat", format == "ogg");
 	config->SetIntValue(ConfigureFLAC::ConfigID, "Preset", preset);
 
-	config->SetIntValue(ConfigureFLAC::ConfigID, "DoMidSideStereo", config->GetIntValue(encoderID, "Use mid-side stereo", False));
-	config->SetIntValue(ConfigureFLAC::ConfigID, "DoExhaustiveModelSearch", config->GetIntValue(encoderID, "Do exhaustive model search", False));
-	config->SetIntValue(ConfigureFLAC::ConfigID, "DoQLPCoeffPrecSearch", config->GetIntValue(encoderID, "Do exhaustive QLP coefficient search", False));
+	config->SetIntValue(ConfigureFLAC::ConfigID, "DoMidSideStereo", midSideStereo);
+	config->SetIntValue(ConfigureFLAC::ConfigID, "DoExhaustiveModelSearch", exhaustiveSearch);
+	config->SetIntValue(ConfigureFLAC::ConfigID, "DoQLPCoeffPrecSearch", qlpCoeffSearch);
 
 	config->SetIntValue(ConfigureFLAC::ConfigID, "Blocksize", Math::Max(192, Math::Min(32768, blocksize)));
 	config->SetIntValue(ConfigureFLAC::ConfigID, "MaxLPCOrder", Math::Max(0, Math::Min(FLAC__MAX_LPC_ORDER, lpc)));
 	config->SetIntValue(ConfigureFLAC::ConfigID, "QLPCoeffPrecision", qlp == 0 ? 0 : Math::Max(FLAC__MIN_QLP_COEFF_PRECISION, Math::Min(FLAC__MAX_QLP_COEFF_PRECISION, qlp)));
-	config->SetIntValue(ConfigureFLAC::ConfigID, "MinResidualPartitionOrder", 0);
 	config->SetIntValue(ConfigureFLAC::ConfigID, "MaxResidualPartitionOrder", Math::Max(0, Math::Min(FLAC__MAX_RICE_PARTITION_ORDER, rice)));
 
 	return True;
