@@ -1,5 +1,5 @@
  /* BoCA - BonkEnc Component Architecture
-  * Copyright (C) 2007-2019 Robert Kausch <robert.kausch@freac.org>
+  * Copyright (C) 2007-2021 Robert Kausch <robert.kausch@freac.org>
   *
   * This program is free software; you can redistribute it and/or
   * modify it under the terms of the GNU General Public License as
@@ -34,7 +34,7 @@ namespace BoCA
 			Array<UnsignedInt32>	 frameOffsets;
 
 			Bool			 FillReservoir(Int = 0);
-			Bool			 IncreaseReservoir(Int, UnsignedByte *);
+			Bool			 IncreaseReservoir(Int, UnsignedByte *, Int = 0);
 
 			Bool			 CheckPrecedingFrame(UnsignedByte *, Int, UnsignedByte *);
 		public:
