@@ -1,5 +1,5 @@
  /* BoCA - BonkEnc Component Architecture
-  * Copyright (C) 2007-2020 Robert Kausch <robert.kausch@freac.org>
+  * Copyright (C) 2007-2021 Robert Kausch <robert.kausch@freac.org>
   *
   * This program is free software; you can redistribute it and/or
   * modify it under the terms of the GNU General Public License as
@@ -63,6 +63,7 @@ const String &BoCA::EncoderSndFile::GetComponentSpecs()
 		      <extension>rf64</extension>									\
 		      <tag id=\"riff-tag\" mode=\"other\">RIFF INFO Tag</tag>						\
 		      <tag id=\"cart-tag\" mode=\"other\">RIFF Cart Tag</tag>						\
+		      <tag id=\"id3v2-tag\" mode=\"other\">ID3v2</tag>							\
 		    </format>												\
 		    <format>												\
 		      <name>Sun Audio Files</name>									\
@@ -353,13 +354,18 @@ Bool BoCA::EncoderSndFile::Deactivate()
 
 			if (tagger != NIL)
 			{
+				Int64	 size = driver->GetPos();
+
+				if (size % 8 > 0) for (Int i = 0; i < 8 - (size % 8); i++) driver->WriteData((unsigned char *) "", 1);
+
 				Buffer<unsigned char>	 tagBuffer;
 
 				tagger->SetConfiguration(config);
 				tagger->RenderBuffer(tagBuffer, track);
 
 				unsigned char	 guid[16] = { 'l', 'i', 's', 't', 0x2F, 0x91, 0xCF, 0x11, 0xA5, 0xD6, 0x28, 0xDB, 0x04, 0xC1, 0x00, 0x00 };
-				Int64		 size	  = tagBuffer.Size() + 16;
+
+				size = tagBuffer.Size() + 16;
 
 				driver->WriteData(guid, 16);
 
@@ -386,9 +392,9 @@ Bool BoCA::EncoderSndFile::Deactivate()
 		driver->Seek(driver->GetSize());
 	}
 
-	/* Write ID3v2 tags to Wave and AIFF files.
+	/* Write ID3v2 tags to Wave, RF64 and AIFF files.
 	 */
-	if (fileFormat == SF_FORMAT_WAV || fileFormat == SF_FORMAT_AIFF)
+	if (fileFormat == SF_FORMAT_WAV || fileFormat == SF_FORMAT_RF64 || fileFormat == SF_FORMAT_AIFF)
 	{
 		/* Write ID3v2 tag if requested.
 		 */
@@ -404,12 +410,12 @@ Bool BoCA::EncoderSndFile::Deactivate()
 				tagger->SetConfiguration(config);
 				tagger->RenderBuffer(id3Buffer, track);
 
-				if (fileFormat == SF_FORMAT_WAV) driver->WriteData((unsigned char *) "id3 ", 4);
-				else				 driver->WriteData((unsigned char *) "ID3 ", 4);
+				if (fileFormat != SF_FORMAT_AIFF) driver->WriteData((unsigned char *) "id3 ", 4);
+				else				  driver->WriteData((unsigned char *) "ID3 ", 4);
 
 				Int	 size = id3Buffer.Size();
 
-				if ((fileFormat == SF_FORMAT_WAV  && endianness == EndianLittle) ||
+				if ((fileFormat != SF_FORMAT_AIFF && endianness == EndianLittle) ||
 				    (fileFormat == SF_FORMAT_AIFF && endianness == EndianBig)) for (Int i = 0; i <= 3; i++) driver->WriteData(((unsigned char *) &size) + i, 1);
 				else							       for (Int i = 3; i >= 0; i--) driver->WriteData(((unsigned char *) &size) + i, 1);
 
@@ -427,7 +433,7 @@ Bool BoCA::EncoderSndFile::Deactivate()
 
 		driver->Seek(4);
 
-		if (fileFormat == SF_FORMAT_WAV)
+		if (fileFormat != SF_FORMAT_AIFF)
 		{
 			if (endianness == EndianLittle)	for (Int i = 0; i <= 3; i++) driver->WriteData(((unsigned char *) &fileSize) + i, 1);
 			else				for (Int i = 7; i >= 4; i--) driver->WriteData(((unsigned char *) &fileSize) + i, 1);
@@ -592,37 +598,59 @@ Bool BoCA::EncoderSndFile::ConvertArguments(Config *config)
 
 	static const String	 encoderID = "sndfile-enc";
 
+	/* Set default values.
+	 */
+#ifdef __APPLE__
+	Int	 defaultFormat = SF_FORMAT_AIFF;
+#else
+	Int	 defaultFormat = SF_FORMAT_WAV;
+#endif
+
+	if (!config->GetIntValue("Settings", "UserSpecifiedConfig", False))
+	{
+		config->SetIntValue(ConfigureSndFile::ConfigID, "Format", defaultFormat);
+		config->SetIntValue(ConfigureSndFile::ConfigID, "SubFormat", 0);
+	}
+
 	/* Get command line settings.
 	 */
-	String	 format = "wav";
+	Int	 format	    = config->GetIntValue(ConfigureSndFile::ConfigID, "Format", defaultFormat);
+	String	 formatName = "wav";
 
-	if (config->GetIntValue(encoderID, "Set Output format", False)) format = config->GetStringValue(encoderID, "Output format", format).ToLower();
+	if	(format == SF_FORMAT_AIFF)  formatName = "aiff";
+	else if (format == SF_FORMAT_CAF)   formatName = "caf";
+	else if (format == SF_FORMAT_W64)   formatName = "w64";
+	else if (format == SF_FORMAT_RF64)  formatName = "rf64";
+	else if (format == SF_FORMAT_AU)    formatName = "au";
+	else if (format == SF_FORMAT_VOC)   formatName = "voc";
+	else if (format == SF_FORMAT_SVX)   formatName = "iff";
+	else if (format == SF_FORMAT_IRCAM) formatName = "sf";
+	else if (format == SF_FORMAT_PAF)   formatName = "paf";
+	else if (format == SF_FORMAT_PVF)   formatName = "pvf";
+	else if (format == SF_FORMAT_WVE)   formatName = "wve";
+	else if (format == SF_FORMAT_HTK)   formatName = "htk";
+	else if (format == SF_FORMAT_AVR)   formatName = "avr";
+
+	if (config->GetIntValue(encoderID, "Set Output format", False)) formatName = config->GetStringValue(encoderID, "Output format", formatName).ToLower();
 
 	/* Set configuration values.
 	 */
-#ifdef __APPLE__
-	Int	 outputFormat = SF_FORMAT_AIFF;
-#else
-	Int	 outputFormat = SF_FORMAT_WAV;
-#endif
+	if	(formatName == "wav" ) format = SF_FORMAT_WAV;
+	else if (formatName == "aiff") format = SF_FORMAT_AIFF;
+	else if (formatName == "caf" ) format = SF_FORMAT_CAF;
+	else if (formatName == "w64" ) format = SF_FORMAT_W64;
+	else if (formatName == "rf64") format = SF_FORMAT_RF64;
+	else if (formatName == "au"  ) format = SF_FORMAT_AU;
+	else if (formatName == "voc" ) format = SF_FORMAT_VOC;
+	else if (formatName == "iff" ) format = SF_FORMAT_SVX;
+	else if (formatName == "sf"  ) format = SF_FORMAT_IRCAM;
+	else if (formatName == "paf" ) format = SF_FORMAT_PAF;
+	else if (formatName == "pvf" ) format = SF_FORMAT_PVF;
+	else if (formatName == "wve" ) format = SF_FORMAT_WVE;
+	else if (formatName == "htk" ) format = SF_FORMAT_HTK;
+	else if (formatName == "avr" ) format = SF_FORMAT_AVR;
 
-	if	(format == "wav" ) outputFormat = SF_FORMAT_WAV;
-	else if (format == "aiff") outputFormat = SF_FORMAT_AIFF;
-	else if (format == "caf" ) outputFormat = SF_FORMAT_CAF;
-	else if (format == "w64" ) outputFormat = SF_FORMAT_W64;
-	else if (format == "rf64") outputFormat = SF_FORMAT_RF64;
-	else if (format == "au"	 ) outputFormat = SF_FORMAT_AU;
-	else if (format == "voc" ) outputFormat = SF_FORMAT_VOC;
-	else if (format == "iff" ) outputFormat = SF_FORMAT_SVX;
-	else if (format == "sf"	 ) outputFormat = SF_FORMAT_IRCAM;
-	else if (format == "paf" ) outputFormat = SF_FORMAT_PAF;
-	else if (format == "pvf" ) outputFormat = SF_FORMAT_PVF;
-	else if (format == "wve" ) outputFormat = SF_FORMAT_WVE;
-	else if (format == "htk" ) outputFormat = SF_FORMAT_HTK;
-	else if (format == "avr" ) outputFormat = SF_FORMAT_AVR;
-
-	config->SetIntValue(ConfigureSndFile::ConfigID, "Format", outputFormat);
-	config->SetIntValue(ConfigureSndFile::ConfigID, "SubFormat", 0);
+	config->SetIntValue(ConfigureSndFile::ConfigID, "Format", format);
 
 	return True;
 }
