@@ -1,5 +1,5 @@
  /* BoCA - BonkEnc Component Architecture
-  * Copyright (C) 2007-2021 Robert Kausch <robert.kausch@freac.org>
+  * Copyright (C) 2007-2022 Robert Kausch <robert.kausch@freac.org>
   *
   * This program is free software; you can redistribute it and/or
   * modify it under the terms of the GNU General Public License as
@@ -33,8 +33,8 @@ namespace BoCA
 			String			 GetStringField(const ID3_Frame &, ID3_FieldID, Bool = True);
 			Int			 SetStringField(ID3_Frame &, ID3_FieldID, const String &, Bool = True);
 
-			String			 GetASCIIField(const ID3_Frame &, ID3_FieldID, Bool = True);
-			Int			 SetASCIIField(ID3_Frame &, ID3_FieldID, const String &, Bool = True);
+			Array<String>		 GetStringListField(const ID3_Frame &, ID3_FieldID, Bool = True);
+			Int			 AddStringListItem(ID3_Frame &, ID3_FieldID, const String &, Bool = True);
 
 			Int			 GetIntegerField(const ID3_Frame &, ID3_FieldID);
 			Int			 SetIntegerField(ID3_Frame &, ID3_FieldID, Int);
