@@ -1,5 +1,5 @@
 ﻿ /* BoCA - BonkEnc Component Architecture
-  * Copyright (C) 2007-2021 Robert Kausch <robert.kausch@freac.org>
+  * Copyright (C) 2007-2022 Robert Kausch <robert.kausch@freac.org>
   *
   * This program is free software; you can redistribute it and/or
   * modify it under the terms of the GNU General Public License as
@@ -204,6 +204,8 @@ Error BoCA::TaggerMP4::RenderStreamInfo(const String &fileName, const Track &tra
 
 	/* Save other metadata atoms.
 	 */
+	if (info.rating >= 0) AddItmfItem(mp4File, "rate", NIL, NIL, String::FromInt(info.rating));
+
 	foreach (const String &pair, info.other)
 	{
 		String	 key   = pair.Head(pair.Find(":"));
@@ -211,21 +213,27 @@ Error BoCA::TaggerMP4::RenderStreamInfo(const String &fileName, const Track &tra
 
 		if (value == NIL) continue;
 
-		if	(key == INFO_ALBUMARTIST)   AddItmfItem(mp4File,  "aART", NIL, NIL, value);
+		if	(key == INFO_ALBUMARTIST)      AddItmfItem(mp4File,  "aART", NIL, NIL, value);
 
-		else if	(key == INFO_CONTENTGROUP)  AddItmfItem(mp4File, L"©grp", NIL, NIL, value);
+		else if	(key == INFO_CONTENTGROUP)     AddItmfItem(mp4File, L"©grp", NIL, NIL, value);
 
-		else if	(key == INFO_COMPOSER)      AddItmfItem(mp4File, L"©wrt", NIL, NIL, value);
+		else if	(key == INFO_COMPOSER)         AddItmfItem(mp4File, L"©wrt", NIL, NIL, value);
 
-		else if	(key == INFO_MOVEMENT)	    AddItmfItem(mp4File, L"©mvi", NIL, NIL, value, MP4_ITMF_BT_INTEGER);
-		else if	(key == INFO_MOVEMENTTOTAL) AddItmfItem(mp4File, L"©mvc", NIL, NIL, value, MP4_ITMF_BT_INTEGER);
-		else if	(key == INFO_MOVEMENTNAME)  AddItmfItem(mp4File, L"©mvn", NIL, NIL, value);
+		else if	(key == INFO_MOVEMENT)	       AddItmfItem(mp4File, L"©mvi", NIL, NIL, value, MP4_ITMF_BT_INTEGER);
+		else if	(key == INFO_MOVEMENTTOTAL)    AddItmfItem(mp4File, L"©mvc", NIL, NIL, value, MP4_ITMF_BT_INTEGER);
+		else if	(key == INFO_MOVEMENTNAME)     AddItmfItem(mp4File, L"©mvn", NIL, NIL, value);
 
-		else if (key == INFO_BPM)	    AddItmfItem(mp4File,  "tmpo", NIL, NIL, value, MP4_ITMF_BT_INTEGER);
+		else if (key == INFO_BPM)	       AddItmfItem(mp4File,  "tmpo", NIL, NIL, value, MP4_ITMF_BT_INTEGER);
 
-		else if	(key == INFO_COPYRIGHT)     AddItmfItem(mp4File,  "cprt", NIL, NIL, value);
+		else if	(key == INFO_COPYRIGHT)        AddItmfItem(mp4File,  "cprt", NIL, NIL, value);
 
-		else if	(key == INFO_LYRICS)	    AddItmfItem(mp4File, L"©lyr", NIL, NIL, pair.Tail(pair.Length() - pair.Find(":") - 1));
+		else if	(key == INFO_LYRICS)	       AddItmfItem(mp4File, L"©lyr", NIL, NIL, pair.Tail(pair.Length() - pair.Find(":") - 1));
+
+		else if	(key == INFO_SORT_ARTIST)      AddItmfItem(mp4File,  "soar", NIL, NIL, value);
+		else if	(key == INFO_SORT_ALBUM)       AddItmfItem(mp4File,  "soal", NIL, NIL, value);
+		else if	(key == INFO_SORT_ALBUMARTIST) AddItmfItem(mp4File,  "soaa", NIL, NIL, value);
+		else if	(key == INFO_SORT_COMPOSER)    AddItmfItem(mp4File,  "soco", NIL, NIL, value);
+		else if	(key == INFO_SORT_TITLE)       AddItmfItem(mp4File,  "sonm", NIL, NIL, value);
 	}
 
 	/* Save generic iTunes metadata.
@@ -240,21 +248,42 @@ Error BoCA::TaggerMP4::RenderStreamInfo(const String &fileName, const Track &tra
 
 		if (value == NIL) continue;
 
-		if	(key == INFO_SUBTITLE)	    AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "SUBTITLE",	     value);
+		if	(key == INFO_SUBTITLE)			   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "SUBTITLE",				value);
 
-		else if	(key == INFO_CONDUCTOR)     AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "CONDUCTOR",     value);
-		else if	(key == INFO_REMIXER)	    AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "REMIXER",	     value);
-		else if	(key == INFO_LYRICIST)	    AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "LYRICIST",	     value);
-		else if	(key == INFO_PRODUCER)	    AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "PRODUCER",	     value);
-		else if	(key == INFO_ENGINEER)	    AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "ENGINEER",	     value);
+		else if	(key == INFO_CONDUCTOR)			   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "CONDUCTOR",				value);
+		else if	(key == INFO_REMIXER)			   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "REMIXER",				value);
+		else if	(key == INFO_LYRICIST)			   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "LYRICIST",				value);
+		else if	(key == INFO_PRODUCER)			   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "PRODUCER",				value);
+		else if	(key == INFO_ENGINEER)			   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "ENGINEER",				value);
 
-		else if	(key == INFO_INITIALKEY)    AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "initialkey",    value);
+		else if	(key == INFO_INITIALKEY)		   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "initialkey",			value);
 
-		else if	(key == INFO_MEDIATYPE)	    AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "MEDIA",	     value);
-		else if	(key == INFO_CATALOGNUMBER) AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "CATALOGNUMBER", value);
-		else if	(key == INFO_BARCODE)	    AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "BARCODE",	     value);
+		else if	(key == INFO_MEDIATYPE)			   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "MEDIA",				value);
+		else if	(key == INFO_CATALOGNUMBER)		   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "CATALOGNUMBER",			value);
+		else if	(key == INFO_BARCODE)			   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "BARCODE",				value);
 
-		else if	(key == INFO_DISCSUBTITLE)  AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "DISCSUBTITLE",  value);
+		else if	(key == INFO_DISCSUBTITLE)		   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "DISCSUBTITLE",			value);
+
+		else if	(key == INFO_SCRIPT)			   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "SCRIPT",				value);
+
+		else if	(key == INFO_ASIN)			   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "ASIN",				value);
+
+		else if	(key == INFO_MUSICBRAINZ_ARTISTID)	   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Artist Id",		value);
+		else if	(key == INFO_MUSICBRAINZ_ALBUMID)	   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Album Id",		value);
+		else if	(key == INFO_MUSICBRAINZ_ALBUMARTISTID)	   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Album Artist Id",	value);
+		else if	(key == INFO_MUSICBRAINZ_WORKID)	   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Work Id",		value);
+		else if	(key == INFO_MUSICBRAINZ_DISCID)	   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Disc Id",		value);
+		else if	(key == INFO_MUSICBRAINZ_TRACKID)	   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Track Id",		value);
+		else if	(key == INFO_MUSICBRAINZ_ORIGINALARTISTID) AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Original Artist Id",	value);
+		else if	(key == INFO_MUSICBRAINZ_ORIGINALALBUMID)  AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Original Album Id",	value);
+		else if	(key == INFO_MUSICBRAINZ_RELEASEGROUPID)   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Release Group Id",	value);
+		else if	(key == INFO_MUSICBRAINZ_RELEASETRACKID)   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Release Track Id",	value);
+		else if	(key == INFO_MUSICBRAINZ_TRMID)		   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz TRM Id",		value);
+
+		else if	(key == INFO_MUSICBRAINZ_RELEASETYPE)	   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Album Type",		value);
+		else if	(key == INFO_MUSICBRAINZ_RELEASESTATUS)	   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Album Status",		value);
+
+		else if	(key == INFO_RELEASECOUNTRY)		   AddItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Album Release Country",	value);
 	}
 
 	/* Save Replay Gain info.
@@ -372,7 +401,7 @@ Error BoCA::TaggerMP4::ParseStreamInfo(const String &fileName, Track &track)
 
 	Info		 info	 = track.GetInfo();
 
-	MP4FileHandle	 mp4File = ex_MP4ReadProvider(fileName.ConvertTo("UTF-8"), NIL);
+	MP4FileHandle	 mp4File = ex_MP4Read(fileName.ConvertTo("UTF-8"));
 
 	if (mp4File == NIL) return Error();
 
@@ -540,24 +569,32 @@ Bool BoCA::TaggerMP4::ParseItmfItems(MP4FileHandle mp4File, Info &info)
 
 			if (value == NIL) continue;
 
-			else if	(code ==  "aART") info.SetOtherInfo(INFO_ALBUMARTIST,	value);
+			else if	(code ==  "rate") info.rating = Math::Min(100, value.ToInt());
 
-			else if	(code == L"©grp") info.SetOtherInfo(INFO_CONTENTGROUP,	value);
+			else if	(code ==  "aART") info.SetOtherInfo(INFO_ALBUMARTIST,	   value);
 
-			else if	(code == L"©wrt") info.SetOtherInfo(INFO_COMPOSER,	value);
+			else if	(code == L"©grp") info.SetOtherInfo(INFO_CONTENTGROUP,	   value);
 
-			if	(code == L"©mvi") info.SetOtherInfo(INFO_MOVEMENT,      value);
-			else if (code == L"©mvc") info.SetOtherInfo(INFO_MOVEMENTTOTAL, value);
-			else if	(code == L"©mvn") info.SetOtherInfo(INFO_MOVEMENTNAME,  value);
+			else if	(code == L"©wrt") info.SetOtherInfo(INFO_COMPOSER,	   value);
+
+			if	(code == L"©mvi") info.SetOtherInfo(INFO_MOVEMENT,         value);
+			else if (code == L"©mvc") info.SetOtherInfo(INFO_MOVEMENTTOTAL,    value);
+			else if	(code == L"©mvn") info.SetOtherInfo(INFO_MOVEMENTNAME,     value);
 
 			else if	(code ==  "tmpo")
 			{
 				if (value.ToInt() > 0) info.SetOtherInfo(INFO_BPM, value);
 			}
 
-			else if	(code ==  "cprt") info.SetOtherInfo(INFO_COPYRIGHT,	value);
+			else if	(code ==  "cprt") info.SetOtherInfo(INFO_COPYRIGHT,	   value);
 
-			else if	(code == L"©lyr") info.SetOtherInfo(INFO_LYRICS,	value);
+			else if	(code == L"©lyr") info.SetOtherInfo(INFO_LYRICS,	   value);
+
+			else if (code ==  "soar") info.SetOtherInfo(INFO_SORT_ARTIST,	   value);
+			else if (code ==  "soal") info.SetOtherInfo(INFO_SORT_ALBUM,	   value);
+			else if (code ==  "soaa") info.SetOtherInfo(INFO_SORT_ALBUMARTIST, value);
+			else if (code ==  "soco") info.SetOtherInfo(INFO_SORT_COMPOSER,	   value);
+			else if (code ==  "sonm") info.SetOtherInfo(INFO_SORT_TITLE,	   value);
 		}
 
 		ex_MP4ItmfItemListFree(items);
@@ -606,6 +643,30 @@ Bool BoCA::TaggerMP4::ParseItmfItems(MP4FileHandle mp4File, Info &info)
 
 			else if (id == "DISCSUBTITLE")	info.SetOtherInfo(INFO_DISCSUBTITLE,  value);
 
+			else if (id == "SCRIPT")	info.SetOtherInfo(INFO_SCRIPT,	      value);
+
+			else if (id == "ASIN")		info.SetOtherInfo(INFO_ASIN,	      value);
+
+			else if (id.StartsWith("MUSICBRAINZ"))
+			{
+				if	(id == "MUSICBRAINZ ARTIST ID")		    info.SetOtherInfo(INFO_MUSICBRAINZ_ARTISTID,	 value);
+				else if	(id == "MUSICBRAINZ ALBUM ID")		    info.SetOtherInfo(INFO_MUSICBRAINZ_ALBUMID,		 value);
+				else if	(id == "MUSICBRAINZ ALBUM ARTIST ID")	    info.SetOtherInfo(INFO_MUSICBRAINZ_ALBUMARTISTID,	 value);
+				else if	(id == "MUSICBRAINZ WORK ID")		    info.SetOtherInfo(INFO_MUSICBRAINZ_WORKID,		 value);
+				else if	(id == "MUSICBRAINZ DISC ID")		    info.SetOtherInfo(INFO_MUSICBRAINZ_DISCID,		 value);
+				else if	(id == "MUSICBRAINZ TRACK ID")		    info.SetOtherInfo(INFO_MUSICBRAINZ_TRACKID,		 value);
+				else if (id == "MUSICBRAINZ ORIGINAL ARTIST ID")    info.SetOtherInfo(INFO_MUSICBRAINZ_ORIGINALARTISTID, value);
+				else if	(id == "MUSICBRAINZ ORIGINAL ALBUM ID")	    info.SetOtherInfo(INFO_MUSICBRAINZ_ORIGINALALBUMID,	 value);
+				else if	(id == "MUSICBRAINZ RELEASE GROUP ID")	    info.SetOtherInfo(INFO_MUSICBRAINZ_RELEASEGROUPID,	 value);
+				else if	(id == "MUSICBRAINZ RELEASE TRACK ID")	    info.SetOtherInfo(INFO_MUSICBRAINZ_RELEASETRACKID,	 value);
+				else if	(id == "MUSICBRAINZ TRM ID")		    info.SetOtherInfo(INFO_MUSICBRAINZ_TRMID,		 value);
+
+				else if	(id == "MUSICBRAINZ ALBUM TYPE")	    info.SetOtherInfo(INFO_MUSICBRAINZ_RELEASETYPE,	 value);
+				else if	(id == "MUSICBRAINZ ALBUM STATUS")	    info.SetOtherInfo(INFO_MUSICBRAINZ_RELEASESTATUS,	 value);
+
+				else if	(id == "MUSICBRAINZ ALBUM RELEASE COUNTRY") info.SetOtherInfo(INFO_RELEASECOUNTRY,		 value);
+			}
+
 			else if (id.StartsWith("REPLAYGAIN"))
 			{
 				if	(id == "REPLAYGAIN_TRACK_GAIN") info.track_gain = value;
@@ -739,6 +800,12 @@ Error BoCA::TaggerMP4::UpdateStreamInfo(const String &fileName, const Track &tra
 
 	RemoveItmfItem(mp4File, L"©lyr");
 
+	RemoveItmfItem(mp4File,  "soar");
+	RemoveItmfItem(mp4File,  "soal");
+	RemoveItmfItem(mp4File,  "soaa");
+	RemoveItmfItem(mp4File,  "soco");
+	RemoveItmfItem(mp4File,  "sonm");
+
 	/* Remove iTunes metadata items too.
 	 */
 	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "LABEL");
@@ -760,6 +827,27 @@ Error BoCA::TaggerMP4::UpdateStreamInfo(const String &fileName, const Track &tra
 
 	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "DISCSUBTITLE");
 
+	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "SCRIPT");
+
+	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "ASIN");
+
+	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Artist Id");
+	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Album Id");
+	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Album Artist Id");
+	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Work Id");
+	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Disc Id");
+	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Track Id");
+	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Original Artist Id");
+	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Original Album Id");
+	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Release Group Id");
+	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Release Track Id");
+	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz TRM Id");
+
+	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Album Type");
+	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Album Status");
+
+	RemoveItmfItem(mp4File, "----", ItmfMeaningiTunes, "MusicBrainz Album Release Country");
+
 	ex_MP4Close(mp4File, 0);
 
 	/* Now render the new metadata.
